/*!
 * @eslint-sets/eslint-config-vue3-ts v2.1.5
 * Eslint config sets for vue3.0 typescript
 * (c) 2021-2022 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
'use strict';

const config = {
  plugins: [
    "prettier"
  ],
  extends: [
    "plugin:vue/vue3-recommended",
    "@eslint-sets/eslint-config-ts",
    "plugin:vitest-globals/recommended",
    "prettier"
  ],
  rules: {
    "vue/max-attributes-per-line": "off",
    "vue/no-v-html": "off",
    "vue/require-default-prop": "off",
    "vue/require-explicit-emits": "off",
    "vue/multi-word-component-names": "off",
    "vue/component-tags-order": [
      "error",
      {
        order: ["template", "script", "style"]
      }
    ]
  },
  globals: {
    h: true,
    jest: "readonly",
    defineProps: "readonly",
    defineEmits: "readonly",
    defineExpose: "readonly",
    withDefaults: "readonly"
  },
  overrides: [
    {
      files: ["**/__tests__/*.{j,t}s?(x)", "**/*.spec.{j,t}s?(x)"],
      env: {
        mocha: true,
        jest: true,
        "vitest-globals/env": true
      },
      rules: {
        "no-console": "off",
        "vue/one-component-per-file": "off"
      }
    },
    {
      files: ["*.vue"],
      parser: "vue-eslint-parser",
      parserOptions: {
        parser: "@typescript-eslint/parser",
        ecmaVersion: 2020,
        sourceType: "module",
        ecmaFeatures: {
          experimentalObjectRestSpread: true,
          experimentalDecorators: true,
          jsx: true,
          tsx: true
        },
        vueFeatures: {}
      },
      rules: {
        "vue/no-v-model-argument": "off",
        "vue/valid-v-model": 0,
        "vue/html-indent": 0
      }
    }
  ]
};

module.exports = config;
